@@ -125,10 +125,8 @@ func getVersion() string {
 	return version
 }
 
-func printVersion() {
-	if verbose {
-		fmt.Fprintf(os.Stderr, "git-credential-oauth %s\n", getVersion())
-	}
+func printVersion(w io.Writer) {
+	fmt.Fprintf(w, "git-credential-oauth %s\n", getVersion())
 }
 
 func parse(input string) map[string]string {
@@ -154,8 +152,12 @@ func main() {
 	flag.BoolVar(&verbose, "verbose", false, "log debug information to stderr")
 	var device bool
 	flag.BoolVar(&device, "device", false, "instead of opening a web browser locally, print a code to enter on another device")
+	var bearer bool
+	flag.BoolVar(&bearer, "bearer", false, "Prefer Bearer authentication for supported hosts")
 	flag.Usage = func() {
-		printVersion()
+		if verbose {
+			printVersion(os.Stderr)
+		}
 		fmt.Fprintln(os.Stderr, "usage: git credential-oauth [<options>] <action>")
 		fmt.Fprintln(os.Stderr, "")
 		fmt.Fprintln(os.Stderr, "Options:")
@@ -165,6 +167,7 @@ func main() {
 		fmt.Fprintln(os.Stderr, "  get            Generate credential [called by Git]")
 		fmt.Fprintln(os.Stderr, "  configure      Configure as Git credential helper")
 		fmt.Fprintln(os.Stderr, "  unconfigure    Unconfigure as Git credential helper")
+		fmt.Fprintln(os.Stderr, "  version        Print version")
 		fmt.Fprintln(os.Stderr, "")
 		fmt.Fprintln(os.Stderr, "See also https://github.com/hickford/git-credential-oauth")
 	}
@@ -182,7 +185,9 @@ func main() {
 	}
 	switch args[0] {
 	case "get":
-		printVersion()
+		if verbose {
+			printVersion(os.Stderr)
+		}
 		input, err := io.ReadAll(os.Stdin)
 		if err != nil {
 			log.Fatalln(err)
@@ -315,16 +320,24 @@ func main() {
 		if verbose {
 			fmt.Fprintln(os.Stderr, "token:", token)
 		}
-		output := map[string]string{
-			"password": token.AccessToken,
-		}
-		if pairs["username"] == "" {
-			if host == "bitbucket.org" {
-				// https://support.atlassian.com/bitbucket-cloud/docs/use-oauth-on-bitbucket-cloud/#Cloning-a-repository-with-an-access-token
-				output["username"] = "x-token-auth"
-			} else {
-				// https://docs.gitlab.com/ee/api/oauth2.html#access-git-over-https-with-access-token
-				output["username"] = "oauth2"
+		// "A capability[] directive must precede any value depending on it and these directives should be the first item announced in the protocol." https://git-scm.com/docs/git-credential
+		fmt.Println("capability[]=authtype")
+		output := map[string]string{}
+		hostSupportsBearer := host == "bitbucket.org" || host == "codeberg.org" || host == "gitea.com" || looksLikeGitea || strings.HasSuffix(host, ".googlesource.com")
+		authtypeCapable := strings.Contains(pairs["capability[]"], "authtype")
+		if bearer && hostSupportsBearer && authtypeCapable {
+			output["authtype"] = "Bearer"
+			output["credential"] = token.AccessToken
+		} else {
+			output["password"] = token.AccessToken
+			if pairs["username"] == "" {
+				if host == "bitbucket.org" {
+					// https://support.atlassian.com/bitbucket-cloud/docs/use-oauth-on-bitbucket-cloud/#Cloning-a-repository-with-an-access-token
+					output["username"] = "x-token-auth"
+				} else {
+					// https://docs.gitlab.com/ee/api/oauth2.html#access-git-over-https-with-access-token
+					output["username"] = "oauth2"
+				}
 			}
 		}
 		if !token.Expiry.IsZero() {
@@ -375,6 +388,12 @@ func main() {
 			}
 		}
 		fmt.Fprintf(os.Stderr, "%sd successfully\n", args[0])
+	case "capability":
+		// https://git-scm.com/docs/git-credential#CAPA-IOFMT
+		fmt.Println("version 0")
+		fmt.Println("capability authtype")
+	case "version":
+		printVersion(os.Stdout)
 	}
 }
 
